'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

var _require = require('chai'),
    expect = _require.expect;

var _require2 = require('../../src'),
    NOT_FOUND = _require2.NOT_FOUND;

var _require3 = require('protractor'),
    browser = _require3.browser,
    element = _require3.element,
    by = _require3.by;

describe('frame-storage-strategy', function () {
  beforeEach(_asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return browser.get('http://localhost:3000');

          case 2:
            _context.next = 4;
            return browser.executeScript('\n    LocalStorageStrategy = DataCapsuleTools.LocalStorageStrategy;\n    FrameStorageListener = DataCapsuleTools.FrameStorageListener;\n    listener = new FrameStorageListener(new LocalStorageStrategy());\n    listener.start((origin, source, token) => token === \'secret\');\n    ');

          case 4:
            _context.next = 6;
            return browser.switchTo().frame(element(by.tagName('iframe')).getWebElement());

          case 6:
            _context.next = 8;
            return browser.executeScript('\n    DataCapsule = DataCapsuleTools.DataCapsule;\n    FrameStorageStrategy = DataCapsuleTools.FrameStorageStrategy;\n    capsule = new DataCapsule({strategy: new FrameStorageStrategy(window.top, \'*\', \'secret\')});\n    ');

          case 8:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  })));

  afterEach(_asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2() {
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return browser.switchTo().frame(null);

          case 2:
            _context2.next = 4;
            return browser.executeScript('localStorage.clear();');

          case 4:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined);
  })));

  it('should store and retrieve information', _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3() {
    var result;
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.next = 2;
            return browser.executeScript('\n    capsule.setItem(\'hey\', \'ho\', {namespace: \'wix\'})\n      .then(() => capsule.getItem(\'hey\', {namespace: \'wix\'}))\n      .then((result) => {\n        const text = window.document.createTextNode(result);\n        window.document.querySelector(\'#result\').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode(\'FAILURE\');\n        window.document.querySelector(\'#result\').appendChild(text);\n      });\n    ');

          case 2:
            _context3.next = 4;
            return browser.findElement(by.id('result')).getText();

          case 4:
            result = _context3.sent;


            expect(result).to.equal('ho');

          case 6:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined);
  })));

  it('should remove items (and handle rejections)', _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4() {
    var result;
    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.next = 2;
            return browser.executeScript('\n    capsule.setItem(\'hey\', \'ho\', {namespace: \'wix\'})\n      .then(() => capsule.removeItem(\'hey\', {namespace: \'wix\'}))\n      .then(() => capsule.getItem(\'hey\', {namespace: \'wix\'}))\n      .then((result) => {\n        const text = window.document.createTextNode(result);\n        window.document.querySelector(\'#result\').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode(e);\n        window.document.querySelector(\'#result\').appendChild(text);\n      });\n    ');

          case 2:
            _context4.next = 4;
            return browser.findElement(by.id('result')).getText();

          case 4:
            result = _context4.sent;

            expect(result).to.equal(NOT_FOUND.message);

          case 6:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, undefined);
  })));

  it('should get all items', _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee5() {
    var result;
    return regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            _context5.next = 2;
            return browser.executeScript('\n    capsule.setItem(\'hey\', \'ho\', {namespace: \'wix\'})\n      .then(() => capsule.getAllItems({namespace: \'wix\'}))\n      .then((result) => {\n        const text = window.document.createTextNode(JSON.stringify(result));\n        window.document.querySelector(\'#result\').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode(e);\n        window.document.querySelector(\'#result\').appendChild(text);\n      });\n    ');

          case 2:
            _context5.next = 4;
            return browser.findElement(by.id('result')).getText();

          case 4:
            result = _context5.sent;

            expect(result).to.equal('{"hey":"ho"}');

          case 6:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, undefined);
  })));

  it('should stop the listener when calling the 🛑 method, and therefore the message won\'t return', _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee6() {
    var result;
    return regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            _context6.next = 2;
            return browser.switchTo().frame(null);

          case 2:
            _context6.next = 4;
            return browser.executeScript('listener.stop()');

          case 4:
            _context6.next = 6;
            return browser.switchTo().frame(element(by.tagName('iframe')).getWebElement());

          case 6:
            _context6.next = 8;
            return browser.executeScript('\n    capsule.setItem(\'hey\', \'ho\', {namespace: \'wix\'})\n      .then(() => capsule.getItem(\'hey\', {namespace: \'wix\'}))\n      .then((result) => {\n        const text = window.document.createTextNode(result);\n        window.document.querySelector(\'#result\').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode(\'FAILURE\');\n        window.document.querySelector(\'#result\').appendChild(text);\n      });\n    ');

          case 8:
            _context6.next = 10;
            return browser.findElement(by.id('result')).getText();

          case 10:
            result = _context6.sent;


            expect(result).to.equal('');

          case 12:
          case 'end':
            return _context6.stop();
        }
      }
    }, _callee6, undefined);
  })));
});

describe('frame-storage-strategy when the token is differenet', function () {
  beforeEach(_asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee7() {
    return regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            _context7.next = 2;
            return browser.get('http://localhost:3000');

          case 2:
            _context7.next = 4;
            return browser.executeScript('\n    LocalStorageStrategy = DataCapsuleTools.LocalStorageStrategy;\n    FrameStorageListener = DataCapsuleTools.FrameStorageListener;\n    listener = new FrameStorageListener(new LocalStorageStrategy());\n    listener.start((origin, source, token) => token === \'secret\');\n    ');

          case 4:
            _context7.next = 6;
            return browser.switchTo().frame(element(by.tagName('iframe')).getWebElement());

          case 6:
            _context7.next = 8;
            return browser.executeScript('\n    DataCapsule = DataCapsuleTools.DataCapsule;\n    FrameStorageStrategy = DataCapsuleTools.FrameStorageStrategy;\n    capsule = new DataCapsule({strategy: new FrameStorageStrategy(window.top, \'*\', \'different-then-secret\')});\n    ');

          case 8:
          case 'end':
            return _context7.stop();
        }
      }
    }, _callee7, undefined);
  })));

  afterEach(_asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee8() {
    return regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            _context8.next = 2;
            return browser.switchTo().frame(null);

          case 2:
            _context8.next = 4;
            return browser.executeScript('localStorage.clear();');

          case 4:
          case 'end':
            return _context8.stop();
        }
      }
    }, _callee8, undefined);
  })));

  it('should send a not authorized message when the message was not authorized by the listener verifier', _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee9() {
    var result;
    return regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            _context9.next = 2;
            return browser.executeScript('\n    capsule.setItem(\'hey\', \'ho\', {namespace: \'wix\'})\n      .then(() => {\n        const text = window.document.createTextNode(\'SUCCESS\');\n        window.document.querySelector(\'#result\').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode(e);\n        window.document.querySelector(\'#result\').appendChild(text);\n      });\n    ');

          case 2:
            _context9.next = 4;
            return browser.findElement(by.id('result')).getText();

          case 4:
            result = _context9.sent;


            expect(result).to.equal('Error: message was not authorized');

          case 6:
          case 'end':
            return _context9.stop();
        }
      }
    }, _callee9, undefined);
  })));
});

describe('frame-storage-strategy with custom host strategy', function () {
  beforeEach(_asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee10() {
    return regeneratorRuntime.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            _context10.next = 2;
            return browser.get('http://localhost:3000');

          case 2:
            _context10.next = 4;
            return browser.executeScript('\n    class MyStorageStrategy extends DataCapsuleTools.BaseStorage {\n      setItem() {\n        return Promise.reject(new Error(\'byebye\'));\n      }\n      getItem() {\n        //\n      }\n      removeItem() {\n        //\n      }\n      getAllItems() {\n        //\n      }\n    }\n\n    FrameStorageListener = DataCapsuleTools.FrameStorageListener;\n    listener = new FrameStorageListener(new MyStorageStrategy());\n    listener.start((origin, source, token) => token === \'secret\');\n    ');

          case 4:
            _context10.next = 6;
            return browser.switchTo().frame(element(by.tagName('iframe')).getWebElement());

          case 6:
            _context10.next = 8;
            return browser.executeScript('\n    DataCapsule = DataCapsuleTools.DataCapsule;\n    FrameStorageStrategy = DataCapsuleTools.FrameStorageStrategy;\n    capsule = new DataCapsule({strategy: new FrameStorageStrategy(window.top, \'*\', \'secret\')});\n    ');

          case 8:
          case 'end':
            return _context10.stop();
        }
      }
    }, _callee10, undefined);
  })));

  afterEach(_asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee11() {
    return regeneratorRuntime.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            _context11.next = 2;
            return browser.switchTo().frame(null);

          case 2:
            _context11.next = 4;
            return browser.executeScript('localStorage.clear();');

          case 4:
          case 'end':
            return _context11.stop();
        }
      }
    }, _callee11, undefined);
  })));

  it('should allow for custom errors to be transmitted over the wire', _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee12() {
    var result;
    return regeneratorRuntime.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            _context12.next = 2;
            return browser.executeScript('\n    capsule.setItem(\'hey\', \'ho\', {namespace: \'wix\'})\n      .then(() => capsule.getItem(\'hey\', {namespace: \'wix\'}))\n      .then((result) => {\n        const text = window.document.createTextNode(\'SUCCESS\');\n        window.document.querySelector(\'#result\').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode(e);\n        window.document.querySelector(\'#result\').appendChild(text);\n      });\n    ');

          case 2:
            _context12.next = 4;
            return browser.findElement(by.id('result')).getText();

          case 4:
            result = _context12.sent;

            expect(result).to.equal('byebye');

          case 6:
          case 'end':
            return _context12.stop();
        }
      }
    }, _callee12, undefined);
  })));
});
//# sourceMappingURL=frame-storage.e2e.js.map
